@@ -104,15 +104,9 @@ def AnalyzeSpeaker(speaker,form):
 @task()
 def doBasicAnalysis(form):
     sp = [x for x in Speaker.objects.all() if str(x) != 's35']
-    if settings.DEBUG:
-        sp = Speaker.objects.filter(Number = 's03')
-        out = AnalyzeSpeaker.delay(sp[0],form)
-    else:
-        #for s in sp:
-        #    AnalyzeSpeaker.delay(s,form)
-        #job = group([AnalyzeSpeaker.s(speaker, form) for speaker in sp])
-        #job.apply_async(link=consolidateResultFiles.s())
-        res = chord((AnalyzeSpeaker.s(s, form) for s in sp), combineResults.s(wanted=form.get_wanted_fields()))()
+    #if settings.DEBUG:
+    #    sp = Speaker.objects.filter(Number = 's03')
+    res = chord((AnalyzeSpeaker.s(s, form) for s in sp), combineResults.s(wanted=form.get_wanted_fields()))()
 
 @task()
 def consolidateResultFiles():
